/* affinity-generic.c */

/*
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 by
 *	University of New Hampshire Interoperability Laboratory
 *	121 Technology Drive, Suite 2
 *	Durham, NH 03824-4716
 *	phone: 1-603-862-0090
 *	fax: 1-603-862-4181
 *	e-mail: info@iol.unh.edu
 * All rights reserved.
 *
 * This file is part of the UNH EXS implementation of the
 * Consortium Specification: Extended Sockets API (ES-API) Issue 1.0,
 * Document Number C050 published by The Open Group, January 2005,
 * and copyright 2005 by The Open Group.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING.GPL in the main directory of this source tree, or the
 * BSD license, available from the file COPYING.BSD in the main directory
 * of this source tree.
 *
 * This material is based upon work supported by the National Science
 * Foundation under Grants No. OCI-1127228 and DGE-0913620.
 *
 * Any opinions, findings, and conclusions or recommendations
 * expressed in this material are those of the authors and do not
 * necessarily reflect the views of the National Science Foundation.
 */

/*
 * The UNH IOL implementation of the Extended Sockets API (ES-API) Issue 1.0
 *
 * defined in:	The Interconnect Software Consortium Issue 1.0
 *		ISBN: 1-931624-52-6
 *		Published by The open Group, January 2005.
 *
 * all page references in this source code are to pages in that document.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define _POSIX_C_SOURCE 200112L
#define _ISOC99_SOURCE
#define _XOPEN_SOURCE 600

#include <errno.h>
#include <pthread.h>
#include <unistd.h>

#include <affinity.h>

/* Sets the affinity of the given thread to the given CPU if newcpu is
 * nonnegative, and returns the previous affinity of the given thread in the
 * buffer pointed to by oldcpu if oldcpu is not NULL.
 *
 * This function is intended to be platform-agnostic, in the absence of a POSIX
 * function to do this.
 *
 * On success, this function returns 0.  On error, error code will be placed
 * into errno and this function will return -1.
 *
 * This function will fail if no memory for CPU sets is available, the number of
 * CPUs in the system cannot be reliably determined, or the affinity cannot be
 * set for some reason. */
int
_exs_set_thread_affinity(pthread_t threadid, int newcpu, int *oldcpu)
{
	/* Squelch warnings about unused parameters */
	(void) threadid;
	(void) newcpu;
	(void) oldcpu;

	errno = ENOTSUP;
	return -1;
}	/* _exs_set_thread_affinity */

/* Returns the number of CPUs that should be used for making CPU sets.  On
 * failure, returns -1 and sets errno to ERANGE. */
int
_exs_cpu_count(void)
{
	errno = ENOTSUP;
	return -1;
}	/* _exs_cpu_count */
